@@ -13,12 +13,13 @@
 
 G_BEGIN_DECLS
 
-G_DECLARE_FINAL_TYPE (SnapdGetAliases, snapd_get_aliases, SNAPD, GET_ALIASES, SnapdRequest)
+G_DECLARE_FINAL_TYPE(SnapdGetAliases, snapd_get_aliases, SNAPD, GET_ALIASES,
+                     SnapdRequest)
 
-SnapdGetAliases *_snapd_get_aliases_new         (GCancellable        *cancellable,
-                                                 GAsyncReadyCallback  callback,
-                                                 gpointer             user_data);
+SnapdGetAliases *_snapd_get_aliases_new(GCancellable *cancellable,
+                                        GAsyncReadyCallback callback,
+                                        gpointer user_data);
 
-GPtrArray       *_snapd_get_aliases_get_aliases (SnapdGetAliases *request);
+GPtrArray *_snapd_get_aliases_get_aliases(SnapdGetAliases *request);
 
 G_END_DECLS
