@@ -13,12 +13,13 @@
 
 G_BEGIN_DECLS
 
-G_DECLARE_FINAL_TYPE (SnapdGetSections, snapd_get_sections, SNAPD, GET_SECTIONS, SnapdRequest)
+G_DECLARE_FINAL_TYPE(SnapdGetSections, snapd_get_sections, SNAPD, GET_SECTIONS,
+                     SnapdRequest)
 
-SnapdGetSections *_snapd_get_sections_new          (GCancellable        *cancellable,
-                                                    GAsyncReadyCallback  callback,
-                                                    gpointer             user_data);
+SnapdGetSections *_snapd_get_sections_new(GCancellable *cancellable,
+                                          GAsyncReadyCallback callback,
+                                          gpointer user_data);
 
-GStrv             _snapd_get_sections_get_sections (SnapdGetSections *request);
+GStrv _snapd_get_sections_get_sections(SnapdGetSections *request);
 
 G_END_DECLS
